@@ -3,19 +3,19 @@
 using namespace Rcpp;
 
 // [[Rcpp::export]]
-List R_hunspell_info(std::string affix, std::string dict){
+List R_hunspell_info(std::string affix, CharacterVector dict){
 
   //init with affix and at least one dict
   hunspell_dict mydict(affix, dict);
   return List::create(
     _["dict"] = dict,
-    _["encoding"] = CharacterVector(mydict.enc()),
-    _["wordchars"] = mydict.string_to_r(mydict.wc())
+    _["encoding"] = mydict.enc(),
+    _["wordchars"] = mydict.r_wordchars()
   );
 }
 
 // [[Rcpp::export]]
-LogicalVector R_hunspell_check(std::string affix, std::string dict, StringVector words){
+LogicalVector R_hunspell_check(std::string affix, CharacterVector dict, StringVector words){
 
   //init with affix and at least one dict
   hunspell_dict mydict(affix, dict);
@@ -24,12 +24,12 @@ LogicalVector R_hunspell_check(std::string affix, std::string dict, StringVector
   LogicalVector out;
   for(int i = 0; i < words.length(); i++)
     out.push_back(mydict.spell(words[i]));
-
   return out;
+
 }
 
 // [[Rcpp::export]]
-List R_hunspell_suggest(std::string affix, std::string dict, StringVector words){
+List R_hunspell_suggest(std::string affix, CharacterVector dict, StringVector words){
 
   //init with affix and at least one dict
   hunspell_dict mydict(affix, dict);
@@ -42,7 +42,7 @@ List R_hunspell_suggest(std::string affix, std::string dict, StringVector words)
 }
 
 // [[Rcpp::export]]
-List R_hunspell_analyze(std::string affix, std::string dict, StringVector words){
+List R_hunspell_analyze(std::string affix, CharacterVector dict, StringVector words){
 
   //init with affix and at least one dict
   hunspell_dict mydict(affix, dict);
@@ -55,7 +55,7 @@ List R_hunspell_analyze(std::string affix, std::string dict, StringVector words)
 }
 
 // [[Rcpp::export]]
-List R_hunspell_stem(std::string affix, std::string dict, StringVector words){
+List R_hunspell_stem(std::string affix, CharacterVector dict, StringVector words){
 
   //init with affix and at least one dict
   hunspell_dict mydict(affix, dict);
